@@ -57,10 +57,9 @@ class SpectrumDocument(Document):
 
     def _make_words(self):
         """Create word from peaks (and losses)."""
-        format_string = "{}@{:." + "{}".format(self.n_decimals) + "f}"
-        peak_words = [format_string.format("peak", mz) for mz in self._obj.peaks.mz]
+        peak_words = [f"peak@{mz:.{self.n_decimals}f}" for mz in self._obj.peaks.mz]
         if self._obj.losses is not None:
-            loss_words = [format_string.format("loss", mz) for mz in self._obj.losses.mz]
+            loss_words = [f"loss@{mz:.{self.n_decimals}f}" for mz in self._obj.losses.mz]
         else:
             loss_words = []
         self.words = peak_words + loss_words
